@@ -2,7 +2,7 @@
 from django import forms
 from django.forms.models import BaseInlineFormSet, inlineformset_factory
 from .models import *
-import autocomplete_light
+from dal import autocomplete
 
 class LineaArticulosManageForm(forms.ModelForm):
     class Meta:
