@@ -2,7 +2,7 @@
 from django import forms
 from django.forms.models import BaseInlineFormSet, inlineformset_factory
 from .models import *
-import autocomplete_light
+from dal import autocomplete
 
 class filtro_clientes_form(forms.Form):
     clave   = forms.CharField(max_length=100,  widget=forms.TextInput(attrs={'class':'input-small', 'placeholder':'Clave...'}),required=False)
