@@ -1,7 +1,7 @@
 #encoding:utf-8
 from django import forms
 
-import autocomplete_light
+from dal import autocomplete
 from django.contrib.auth.models import User
 from django.forms.models import BaseInlineFormSet, inlineformset_factory
 from .models import *
